@@ -225,6 +225,7 @@ class EncodeFile:
         step_run_id: str,
         submitted_file_name: Optional[str] = None,
         genome_annotation: Optional[str] = None,
+        pseudo_haplotype: Optional[str] = None,
         extras: Optional[Dict[str, Any]] = None,
     ) -> Dict[str, Any]:
         """
@@ -253,6 +254,8 @@ class EncodeFile:
             obj["filter_type"] = file_params.filter_type
         if file_params.filter_value is not None:
             obj["filter_value"] = file_params.filter_value
+        if file_params.pseudo_haplotype is not None:
+            obj["pseudo_haplotype"] = file_params.pseudo_haplotype
         if extras is not None:
             obj.update(extras)
         obj[Connection.PROFILE_KEY] = "file"
@@ -328,17 +331,27 @@ class EncodeAnalysis:
         return payload
 
 
-class EncodeExperiment:
+class DatasetType(Enum):
+    Annotation = "Annotation"
+    Experiment = "Experiment"
+    AggregateSeries = "AggregateSeries"
+
+
+class EncodeDataset:
     INTERNAL_STATUS_KEY = "internal_status"
     INTERNAL_STATUS_POST_ACCESSIONING = "pipeline completed"
     ALLOWED_REPLICATE_STATUSES = ("released", "in progress")
 
-    def __init__(self, portal_experiment: Dict[str, Any]):
-        self.at_id = portal_experiment["@id"]
-        self.portal_properties = portal_experiment
+    def __init__(self, portal_properties: Dict[str, Any]):
+        self.at_id = portal_properties["@id"]
+        self.portal_properties = portal_properties
 
     @property
     def assay_term_name(self) -> str:
+        assay_term_name = self.portal_properties["assay_term_name"]
+        # could happen when posting QC to AggregateSeries where assay_term_name is an array
+        if type(assay_term_name) == list:
+            return assay_term_name[0]
         return self.portal_properties["assay_term_name"]
 
     @property
@@ -349,6 +362,14 @@ class EncodeExperiment:
     def accession(self) -> str:
         return self.at_id.split("/")[-2]
 
+    @property
+    def dataset_type(self) -> DatasetType:
+        dataset_type = self.portal_properties["@type"][0]
+        for type_ in DatasetType:
+            if dataset_type == type_.value:
+                return type_
+        raise ValueError(f"Dataset type {dataset_type} is not supported")
+
     def get_number_of_biological_replicates(self) -> int:
         bio_reps = set(
             [
